@@ -33,25 +33,62 @@ def decode_image(image_data, IMAGE_SIZE):
 	return image
 
 def read_labeled_tfrecord(example):
-	print("Enter the dictionary of Labeled_TFREC_FORMAT\n")
-	dictionary = eval(input())
-	print("Enter Image Size; Example Format ->  192,192  (w/o brackets)\n\n")
-	IMAGE_SIZE = input()
+	
+	global dictionary_labeled
+	global IMAGE_SIZE
+	global tmp_d_l
+	global tmp_img_sz
+	
+	tmp_d_l = dictionary_labeled
+	tmp_img_sz = IMAGE_SIZE
+	
+	if dictionary_labeled is None:
+		print("Enter the dictionary of Labeled_TFREC_FORMAT\n")
+		dictionary = eval(input())
+	else:
+		dictionary = eval(dictionary_labeled)
+	
+	if IMAGE_SIZE is None:
+		print("Enter Image Size; Example Format ->  192,192  (w/o brackets)\n\n")
+		IMAGE_SIZE = input()
+		
 	IMAGE_SIZE = [int(IMAGE_SIZE.split(',')[0]), int(IMAGE_SIZE.split(',')[1])]
 	example = tf.io.parse_single_example(example, dictionary)
 	image = decode_image(example[list(dictionary.keys())[0]], IMAGE_SIZE)
 	label = tf.cast(example[list(dictionary.keys())[1]], tf.int32)
+	
+	dictionary_labeled = tmp_d_l
+	IMAGE_SIZE = tmp_img_sz
+	
 	return image, label
 
 def read_unlabeled_tfrecord(example):
-	print("Enter the dictionary of the UnLabeled_TFREC_FORMAT\n")
-	dictionary = eval(input())
-	print("Enter Image Size; Example Format ->  192,192  (w/o brackets)\n\n")
-	IMAGE_SIZE = input()
+	
+	global dictionary_unlabeled
+	global IMAGE_SIZE
+	global tmp_d_ul
+	global tmp_img_sz
+	
+	tmp_d_ul = dictionary_unlabeled
+	tmp_img_sz = IMAGE_SIZE
+	
+	
+	if dictionary_unlabeled is None:
+		print("Enter the dictionary of the UnLabeled_TFREC_FORMAT\n")
+		dictionary = eval(input())
+	else:
+		dictionary = eval(dictionary_unlabeled)
+	
+	if IMAGE_SIZE is None:
+		print("Enter Image Size; Example Format ->  192,192  (w/o brackets)\n\n")
+		IMAGE_SIZE = input()
 	IMAGE_SIZE = [int(IMAGE_SIZE.split(',')[0]), int(IMAGE_SIZE.split(',')[1])]
 	example = tf.io.parse_single_example(example, dictionary)
 	image = decode_image(example[list(dictionary.keys())[0]], IMAGE_SIZE)
 	idnum = example[list(dictionary.keys())[1]]
+	dictionary_unlabeled = tmp_d_ul
+	IMAGE_SIZE = tmp_img_sz
+	
 	return image, idnum
 
 
